ConsumerUsage

Struct ConsumerUsage 

pub struct ConsumerUsage {
    pub pid: u32,
    pub free: usize,
    pub available: usize,
}
for a given consumer (used) this provides information about the data that’s available to it and the free space the producer has to put data before running into that consumers get offset.

Fields

pid: u32free: usizeavailable: usize