pub struct ConsumerUsage {
pub pid: u32,
pub free: usize,
pub available: usize,
}Expand description
for a given consumer (used) this provides information about the data that’s available to it and the free space the producer has to put data before running into that consumers get offset.
Fields
pid: u32free: usizeavailable: usizeTrait Implementations
Sourceimpl Debug for ConsumerUsage
impl Debug for ConsumerUsage
Sourceimpl PartialEq for ConsumerUsage
impl PartialEq for ConsumerUsage
Sourcefn eq(&self, other: &ConsumerUsage) -> bool
fn eq(&self, other: &ConsumerUsage) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ConsumerUsage